nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Rxcfg

Enum Rxcfg 

#[repr(u8)]
pub enum Rxcfg { RETURNS_RECEIVED_DATA_AND_CLEARS_RX_DATA_FLAG = 0, WHEN_ADDRESS_VALID_FLAG_SET_RETURNS_ADDRESS_STATUS_AND_CLEARS_ADDRESS_VALID_FLAG = 1, }

Variants



RETURNS_RECEIVED_DATA_AND_CLEARS_RX_DATA_FLAG = 0

Reading the Receive Data register returns received data and clears the Receive Data flag.



WHEN_ADDRESS_VALID_FLAG_SET_RETURNS_ADDRESS_STATUS_AND_CLEARS_ADDRESS_VALID_FLAG = 1

Reading the Receive Data register when the Address Valid flag (SSR[AVF]) is set, returns the Address Status register and clear the Address Valid flag. Reading the Receive Data register when the Address Valid flag is clear, returns received data and clears the Receive Data flag (MSR[RDF]).

Implementations

Source

impl Rxcfg

pub const fn from_bits(val: u8) -> Rxcfg

pub const fn to_bits(self) -> u8